==> billogram-foundation-3.13.10.tgz: package/modules/components/dropdown/DropdownContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import Dropdown from './Dropdown';
import DropdownContainer, { changeType, collapseType, expandType } from './DropdownContainer';

import dropdownChange from './redux/dropdownChange';
import dropdownCollapse from './redux/dropdownCollapse';
import dropdownExpand from './redux/dropdownExpand';
import dropdownState from './redux/dropdownState';
import dropdownValueOptionState from './option-value/dropdownValueOptionState';

import createStore from '../../test-utils/createStore';


const TestDropdown = Dropdown({
    block: purebem.of('test-dropdown'),
    displayName: 'TestDropdown'
});

const TestDropdownContainer = DropdownContainer({
    Component: TestDropdown
});

const actionTypePrefix = 'TEST-DROPDOWN';
const path = 'component';
const root = 'test';

test('should dispatch change event when clicking new option', () => {
    const store = createStore({
        [root]: {
            [path]: dropdownState({
                expanded: true,
                options: [
                    dropdownValueOptionState({ text: 'A', value: 'a' }),
                    dropdownValueOptionState({ text: 'B', value: 'b' }),
                    dropdownValueOptionState({ text: 'C', value: 'c' })
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );


    const options = provider.find('TestDropdownValueOption');
    expect(options.length).toBe(3);

    options.at(1).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(2); // change, and collapse
    expect(actions[0]).toEqual(dropdownChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: 'b'
    }));
});

test('should dispatch expand event when clicked and collapsed', () => {
    const store = createStore({
        [root]: {
            [path]: dropdownState({
                options: [
                    dropdownValueOptionState()
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find(TestDropdownContainer).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownExpand({
        path,
        root,
        type: expandType(actionTypePrefix)
    }));
});

test('should dispatch collapse event when clicked and expanded', () => {
    const store = createStore({
        [root]: {
            [path]: dropdownState({
                expanded: true,
                options: [
                    dropdownValueOptionState()
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find(TestDropdownContainer).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownCollapse({
        path,
        root,
        type: collapseType(actionTypePrefix)
    }));
});

test('should read values from store', () => {
    const options = [
        dropdownValueOptionState({ value: 'a' }),
        dropdownValueOptionState({ value: 'b' })
    ];

    const store = createStore({
        [root]: {
            [path]: dropdownState({
                expanded: true,
                highlightedIndex: 1,
                options,
                value: 'b'
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    const component = provider.find(TestDropdown);
    expect(component.prop('expanded')).toBe(true);
    expect(component.prop('highlightedIndex')).toBe(1);
    expect(component.prop('options')).toEqual(options);
    expect(component.prop('value')).toBe('b');
});

==> billogram-foundation-4.0.0.tgz: package/modules/components/dropdown/DropdownContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { Provider } from 'react-redux';
import { mount } from 'enzyme';

import Dropdown from './Dropdown';
import DropdownContainer, { changeType } from './DropdownContainer';

import dropdownChange from './redux/dropdownChange';
import dropdownState from './redux/dropdownState';
import dropdownValueOptionState from './option-value/dropdownValueOptionState';

import createStore from '../../test-utils/createStore';


const TestDropdown = Dropdown({
    block: purebem.of('test-dropdown'),
    closeOnClickOutside: false,
    displayName: 'TestDropdown'
});

const TestDropdownContainer = DropdownContainer({
    Component: TestDropdown
});

const actionTypePrefix = 'TEST-DROPDOWN';
const path = 'component';
const root = 'test';

test('should dispatch change event when clicking new option', () => {
    const store = createStore({
        [root]: {
            [path]: dropdownState({
                options: [
                    dropdownValueOptionState({ text: 'A', value: 'a' }),
                    dropdownValueOptionState({ text: 'B', value: 'b' }),
                    dropdownValueOptionState({ text: 'C', value: 'c' })
                ]
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    const dropdown = provider.find('TestDropdownContainer').first();
    dropdown.simulate('click');

    const options = provider.find('TestDropdownValueOption');
    expect(options.length).toBe(3);

    options.at(1).simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(dropdownChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: 'b'
    }));
});

test('should read values from store', () => {
    const options = [
        dropdownValueOptionState({ value: 'a' }),
        dropdownValueOptionState({ value: 'b' })
    ];

    const store = createStore({
        [root]: {
            [path]: dropdownState({
                options,
                value: 'b'
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestDropdownContainer
                actionTypePrefix={ actionTypePrefix }
                path={ path }
                root={ root } />
        </Provider>
    );

    const component = provider.find(TestDropdown);
    expect(component.prop('options')).toEqual(options);
    expect(component.prop('value')).toBe('b');
});
